@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from enum import Enum
 
-from agentbox.envd.filesystem_agentbox.filesystem_pb2 import EventType
+from agentbox.envd.filesystem_agentbox.filesystem_pb2 import AgentBoxFileType
 
 
-class FilesystemEventType(Enum):
+class AgentBoxFilesystemEventType(Enum):
     """
     Enum representing the type of filesystem event.
     """
@@ -31,21 +31,21 @@ class FilesystemEventType(Enum):
     """
 
 
-def map_event_type(event: EventType):
-    if event == EventType.EVENT_TYPE_CHMOD:
-        return FilesystemEventType.CHMOD
-    elif event == EventType.EVENT_TYPE_CREATE:
-        return FilesystemEventType.CREATE
-    elif event == EventType.EVENT_TYPE_REMOVE:
-        return FilesystemEventType.REMOVE
-    elif event == EventType.EVENT_TYPE_RENAME:
-        return FilesystemEventType.RENAME
-    elif event == EventType.EVENT_TYPE_WRITE:
-        return FilesystemEventType.WRITE
+def map_event_type(event: AgentBoxFileType):
+    if event == AgentBoxFileType.EVENT_TYPE_CHMOD:
+        return AgentBoxFilesystemEventType.CHMOD
+    elif event == AgentBoxFileType.EVENT_TYPE_CREATE:
+        return AgentBoxFilesystemEventType.CREATE
+    elif event == AgentBoxFileType.EVENT_TYPE_REMOVE:
+        return AgentBoxFilesystemEventType.REMOVE
+    elif event == AgentBoxFileType.EVENT_TYPE_RENAME:
+        return AgentBoxFilesystemEventType.RENAME
+    elif event == AgentBoxFileType.EVENT_TYPE_WRITE:
+        return AgentBoxFilesystemEventType.WRITE
 
 
 @dataclass
-class FilesystemEvent:
+class AgentBoxFilesystemEvent:
     """
     Contains information about the filesystem event - the name of the file and the type of the event.
     """
@@ -54,7 +54,7 @@ class FilesystemEvent:
     """
     Relative path to the filesystem object.
     """
-    type: FilesystemEventType
+    type: AgentBoxFilesystemEventType
     """
     Filesystem operation event type.
     """
