@@ -90,6 +90,20 @@ class ADBShell:
             raise ValueError("Invalid adb path")
 
     async def connect(self):
+        # 替换空闲端口(初始化时不抢占端口，连接时进行空闲端口查找和占用)
+        free_port, sock = self._get_free_port_above()
+        self._forwarder_command = self._forwarder_command.replace("11000:", f"{free_port}:")
+        self._connect_command = self._connect_command.replace(":11000", f":{free_port}")
+        self._adb_auth_command = self._adb_auth_command.replace(":11000", f":{free_port}")
+        match_connect = re.search(r"adb connect ([\d.]+:\d+)", self._connect_command)
+        # 替换remote_addr serial
+        if match_connect:
+            self.remote_addr = match_connect.group(1)
+            self.serial = match_connect.group(1)
+        else:
+            raise ValueError("Invalid adb connect command")
+        self._sock = sock
+
         """完成：SSH 转发 -> ADB connect -> adb_auth -> 获取 device"""
         await _retry_async(self._start_ssh_forward, max_retries=3, delay=1, name="SSH forward")
         await _retry_async(self._adb_connect, max_retries=5, delay=1, name="adb connect")
@@ -141,33 +155,34 @@ class ADBShell:
         transport = client.get_transport()
 
         class ForwardServer(threading.Thread):
-            def __init__(self, f_local_port, f_remote_host, f_remote_port, f_transport):
+            def __init__(self, f_local_port, f_remote_host, f_remote_port, f_transport, sock: socket):
                 super().__init__()
                 self.local_port = f_local_port
                 self.remote_host = f_remote_host
                 self.remote_port = f_remote_port
                 self.transport = f_transport
                 self._stopped = threading.Event()
+                self._sock = sock
 
             def stop(self):
                 self._stopped.set()
 
             def run(self):
-                try:
-                    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-                    sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-                    sock.bind(('localhost', self.local_port))
-                    sock.listen(100)
-                except Exception as e:
-                    print(f"Failed to bind local port {self.local_port}: {e}")
-                    return
+                # try:
+                    # sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                    # sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+                    # sock.bind(('localhost', self.local_port))
+                    # sock.listen(100)
+                # except Exception as e:
+                #     print(f"Failed to bind local port {self.local_port}: {e}")
+                #     return
 
                 print(f"Forwarding local port {self.local_port} to {self.remote_host}:{self.remote_port}")
 
                 while not self._stopped.is_set():
-                    r, w, x = select.select([sock], [], [], 1)
-                    if sock in r:
-                        client_sock, addr = sock.accept()
+                    r, w, x = select.select([self._sock], [], [], 1)
+                    if self._sock in r:
+                        client_sock, addr = self._sock.accept()
                         # 建立SSH通道
                         try:
                             chan = self.transport.open_channel('direct-tcpip',
@@ -197,11 +212,24 @@ class ADBShell:
 
                         threading.Thread(target=handler, args=(chan, client_sock), daemon=True).start()
 
-                sock.close()
+                self._sock.close()
 
-        self._forward_server = ForwardServer(local_port, remote_host, remote_port, transport)
+        self._forward_server = ForwardServer(local_port, remote_host, remote_port, transport, self._sock)
         self._forward_server.start()
         self._ssh_client = client
+        
+    def _get_free_port_above(self, start_port=11000, host='0.0.0.0'):
+        """从 start_port 往上找第一个可用端口并立即占用"""
+        for port in range(start_port, 65535):
+            try:
+                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+                s.bind((host, port))
+                s.listen(100)
+                return port, s  # 返回端口号和 socket 对象
+            except OSError:
+                continue
+        raise RuntimeError(f"Failed to find free port above: {start_port}")
 
     def _adb_connect(self):
         if self._connect_command:
