@@ -16,7 +16,7 @@ from agentbox.sandbox_async.filesystem.filesystem import AgentBoxFilesystem as F
 from agentbox.sandbox_async.commands.command import Commands
 from agentbox.sandbox_async.commands.pty import Pty
 from agentbox.sandbox_async.sandbox_api import SandboxApi, SandboxInfo
-from agentbox.api.client.models import SandboxADB
+from agentbox.api.client.models import SandboxADB, InstanceAuthInfo
 from agentbox.sandbox_async.filesystem_ssh.filesystem_ssh import SSHFilesystem
 from agentbox.sandbox_async.commands_ssh.command_ssh import SSHCommands
 from agentbox.sandbox_async.commands_ssh2.command_ssh2 import SSHCommands2
@@ -631,3 +631,26 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
             sandbox_id=self.sandbox_id,
             **config_dict,
         )
+    
+    async def get_instance_auth_info(  # type: ignore
+        self,
+        valid_time: Optional[int] = None,
+        request_timeout: Optional[float] = None,
+    ) -> InstanceAuthInfo:
+        """
+        Get sandbox instance auth info.
+        :param request_timeout: Timeout for the request in **seconds**
+        :return: Sandbox instance auth info
+        """
+        config_dict = self.connection_config.__dict__
+        config_dict.pop("access_token", None)
+        config_dict.pop("api_url", None)
+
+        if request_timeout:
+            config_dict["request_timeout"] = request_timeout
+
+        return await SandboxApi.get_instance_auth_info(
+            sandbox_id=self.sandbox_id,
+            valid_time=valid_time,
+            **config_dict,
+        )
