@@ -224,6 +224,7 @@ class SandboxApi(SandboxApiBase):
         request_timeout: Optional[float] = None,
         headers: Optional[Dict[str, str]] = None,
         proxy: Optional[ProxyTypes] = None,
+        valid_time: Optional[int] = None,
     ) -> InstanceAuthInfo:
         """
         Get the sandbox instance auth info(userId, instanceNo, accessKey, accessSecretKey, expireTime).
@@ -252,6 +253,7 @@ class SandboxApi(SandboxApiBase):
             res = await get_sandboxes_sandbox_id_instance_auth_info.asyncio_detailed(
                 sandbox_id,
                 client=api_client,
+                valid_time=valid_time,
             )
 
             if res.status_code >= 300:
